BleCharacteristicNotification class abstract

Available extensions
Annotations
  • @freezed

Constructors

BleCharacteristicNotification({required String macAddress, required String serviceUuid, required String characteristicUuid, @UintListConverter() required Uint8List value})
BleCharacteristicNotification is the notification received from a BLE characteristic. It contains the MAC address of the device, the UUID of the service,
const
factory
BleCharacteristicNotification.fromJson(Map<String, dynamic> json)
factory

Properties

characteristicUuid String
characteristicUuid is the UUID of the characteristic.
no setterinherited
copyWith → $BleCharacteristicNotificationCopyWith<BleCharacteristicNotification>
Create a copy of BleCharacteristicNotification with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
macAddress String
macAddress is the MAC address of the device.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceUuid String
serviceUuid is the UUID of the service.
no setterinherited
value Uint8List
payload is the data received from the characteristic.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_BleCharacteristicNotification value)) → TResult

Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_BleCharacteristicNotification value)?) → TResult?

Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_BleCharacteristicNotification value)?, {required TResult orElse()}) → TResult

Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String macAddress, String serviceUuid, String characteristicUuid, Uint8List value)?, {required TResult orElse()}) → TResult

Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this BleCharacteristicNotification to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String macAddress, String serviceUuid, String characteristicUuid, Uint8List value)) → TResult

Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String macAddress, String serviceUuid, String characteristicUuid, Uint8List value)?) → TResult?

Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited