BleCharacteristicNotification class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- BleCharacteristicNotification({required String macAddress, required String serviceUuid, required String characteristicUuid, @UintListConverter() required Uint8List value})
-
BleCharacteristicNotification is the notification received from a BLE characteristic.
It contains the MAC address of the device, the UUID of the service,
constfactory
-
BleCharacteristicNotification.fromJson(Map<
String, dynamic> json) -
factory
Properties
- characteristicUuid → String
-
characteristicUuidis the UUID of the characteristic.no setterinherited -
copyWith
→ $BleCharacteristicNotificationCopyWith<
BleCharacteristicNotification> -
Create a copy of BleCharacteristicNotification
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- macAddress → String
-
macAddressis the MAC address of the device.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceUuid → String
-
serviceUuidis the UUID of the service.no setterinherited - value → Uint8List
-
payloadis the data received from the characteristic.no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_BleCharacteristicNotification value)) → TResult -
Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_BleCharacteristicNotification value)?) → TResult? -
Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_BleCharacteristicNotification value)?, {required TResult orElse()}) → TResult -
Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String macAddress, String serviceUuid, String characteristicUuid, Uint8List value)?, {required TResult orElse()}) → TResult -
Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this BleCharacteristicNotification to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String macAddress, String serviceUuid, String characteristicUuid, Uint8List value)) → TResult -
Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String macAddress, String serviceUuid, String characteristicUuid, Uint8List value)?) → TResult? -
Available on BleCharacteristicNotification, provided by the BleCharacteristicNotificationPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited